@@ -1,6 +1,6 @@
 print('importing hello world functions')
 
 from .hello_world import say_hello_world
-from .hello_world_2 import say_hello_again
+# from .hello_world_2 import say_hello_again
 
 print('Imported hello world functions')
\ No newline at end of file
